==> psychoevals-0.5.tar.gz: psychoevals-0.5/psychoevals/agents/myers_briggs/mbti_statements.py <==
mbti_statements = {
    "E-I": [
        "I find it easy to approach new people.",
        "I often feel more energized after socializing.",
        "I enjoy being the center of attention.",
        "I prefer socializing in large groups.",
        "I find it easy to make small talk.",
        "I am more comfortable in social situations than being alone.",
        "I enjoy meeting new people and making friends.",
        "I am outgoing and sociable.",
        "I find it easy to strike up a conversation with strangers."
    ],
    "S-N": [
        "I prefer abstract ideas over concrete facts.",
        "I prefer to focus on the bigger picture rather than the details.",
        "I am more interested in future possibilities than present realities.",
        "I often think about how things could be improved.",
        "I enjoy discussing theories and concepts.",
        "I often get lost in thought and daydreams.",
        "I find it easy to understand complex ideas and theories.",
        "I enjoy learning about new and innovative ideas.",
        "I enjoy thinking about hypothetical scenarios and possibilities."
    ],
    "T-F": [
        "I make decisions based on logic and reason.",
        "I consider how my decisions will affect others.",
        "When solving problems, I prioritize finding the best solution over preserving harmony.",
        "I am more focused on my feelings than objective criteria when making decisions.",
        "I am more objective than subjective.",
        "I enjoy discussing my values and personal beliefs.",
        "I find it important to analyze situations logically.",
        "I prefer to focus on facts and details rather than emotions when making decisions.",
        "I focus on finding the most efficient solution to a problem."
    ],
    "J-P": [
        "I prefer to make plans and follow them.",
        "I like to have flexibility in my plans and options.",
        "I like to make lists and schedules to organize my tasks.",
        "I often act spontaneously and see where the situation takes me.",
        "I prefer to follow routines.",
        "I am adaptable and can adjust to new situations easily.",
        "I prefer to keep my options open rather than commit to a single choice.",
        "I like to have a clear plan of action when working on projects.",
        "I am comfortable with last-minute changes and surprises."
    ]
}

==> psychoevals-0.6.tar.gz: psychoevals-0.6/psychoevals/agents/myers_briggs/mbti_statements.py <==
mbti_statements = {
    "E-I": [
        "I find it easy to approach new people.",
        "I often feel more energized after socializing.",
        "I enjoy being the center of attention.",
        "I prefer socializing in large groups.",
        "I find it easy to make small talk.",
        "I am more comfortable in social situations than being alone.",
        "I enjoy meeting new people and making friends.",
        "I am outgoing and sociable.",
        "I find it easy to strike up a conversation with strangers."
    ],
    "N-S": [
        "I prefer abstract ideas over concrete facts.",
        "I prefer to focus on the bigger picture rather than the details.",
        "I am more interested in future possibilities than present realities.",
        "I often think about how things could be improved.",
        "I enjoy discussing theories and concepts.",
        "I often get lost in thought and daydreams.",
        "I find it easy to understand complex ideas and theories.",
        "I enjoy learning about new and innovative ideas.",
        "I enjoy thinking about hypothetical scenarios and possibilities."
    ],
    "T-F": [
        "I make decisions based on logic and reason.",
        "I consider how my decisions will affect others.",
        "When solving problems, I prioritize finding the best solution over preserving harmony.",
        "I am more focused objective criteria when making decisions than my feelings.",
        "I am more objective than subjective.",
        "I don't enjoy discussing my values and personal beliefs.",
        "I find it important to analyze situations logically.",
        "I prefer to focus on facts and details rather than emotions when making decisions.",
        "I focus on finding the most efficient solution to a problem."
    ],
    "J-P": [
        "I prefer to have a structured and organized environment.",
        "I like to make decisions and stick to them.",
        "I enjoy setting goals and working towards them.",
        "I feel more comfortable when I have a plan.",
        "I tend to be punctual and meet deadlines.",
        "I prefer to finish projects before starting new ones.",
        "I like to follow routines and schedules.",
        "I prefer to work in a systematic and methodical way.",
        "I value order and predictability in my life."
    ]
}
